export interface IDatabase {
    insert(tableName: string, values: {
        [key: string]: unknown;
    }): number;
    upsert(tableName: string, values: {
        [key: string]: unknown;
    }): Promise<unknown>;
    replace(tableName: string, values: {
        [key: string]: unknown;
    }): number;
    update(tableName: string, values: {
        [key: string]: unknown;
    }, whereClause: string, whereArs: Array<unknown>): number;
    delete(tableName: string, whereClause?: string, whereArs?: Array<unknown>): number;
    select<T>(sql: string, conditionParams?: Array<unknown>): QueryProcessor<T>;
    query<T>(param: {
        tableName: string;
        columns?: Array<string>;
        selection?: string;
        selectionArgs?: Array<unknown>;
        groupBy?: string;
        having?: string;
        orderBy?: string;
        limit?: string;
    }): QueryProcessor<T>;
    execSQL(sql: string): void;
    beginTransact(): void;
    commit(): void;
    rollback(): void;
    close(): void;
    isClose(): boolean;
}
export declare const enum ReturnType {
    AS_OBJECT = 0,
    AS_ARRAY = 1
}
export interface DbCreationOptions {
    version?: number;
    createTableScriptsFn?: () => Array<string>;
    dropTableScriptsFn?: () => Array<string>;
    returnType?: ReturnType;
}
export declare function parseToDbValue(value: unknown): string | number;
export declare function parseToJsValue(value: unknown): unknown;
export declare function runInitialDbScript(currDbVersion: number, options: DbCreationOptions, callback: (script: string) => void): void;
export declare class QueryProcessor<T> {
    private _executorFn;
    constructor(executorFn: ExecutorType);
    process<R>(transformer?: ReducerCallback<R>, initialValue?: R): Promise<T>;
    process<R>(transformer?: MapCallback<R>): Promise<T>;
    asGenerator<R>(transformer?: MapCallback<R>): Promise<IterableIterator<T>>;
}
declare type ExecutorType = (transformer: TransformerType<unknown>, resolve?: (args: unknown) => void, reject?: (err: Error) => void) => void;
export declare type MapCallback<R> = (row: unknown, index: number) => R;
export declare type ReducerCallback<R> = ((accumulator: R, row: unknown, index: number) => R);
export declare type TransformerType<R> = {
    transform: ReducerCallback<R> | MapCallback<R>;
    initialValue?: R;
    type: number;
};
export declare enum FIELD_TYPE {
    NULL_ANDROID = 0,
    NULL_SQLITE = 5,
    INTEGER = 1,
    FLOAT = 2,
    STRING = 3,
    BLOB = 4
}
export declare function readDbValue(fieldType: FIELD_TYPE, index: number, callback: (colIndex: number, type: FIELD_TYPE) => unknown): unknown;
export declare function replaceQuestionMark(target: string, values: Array<unknown>): string;
export {};
