export function parseToDbValue(value) {
    if (value === 0)
        return value;
    if (value === "")
        return "''";
    if (value && value instanceof Function)
        return null;
    if ((value && typeof value === "object" && value.constructor === Object) ||
        (value && typeof value === "object" && value.constructor === Array) ||
        (value && typeof value === "object" && value.constructor.constructor === Function)) {
        value = JSON.stringify(value);
    }
    return Number(value) || ((value && `'${value.toString().replace(/'/g, "''")}'`) || null);
}
export function parseToJsValue(value) {
    try {
        return JSON.parse(value);
    }
    catch (_a) { }
    return value;
}
export function runInitialDbScript(currDbVersion, options, callback) {
    if (options.version < currDbVersion) {
        throw new Error(`It is not possible to set the version ${options.version} to database, because is lower then current version, Db current version is
            ${currDbVersion}`);
    }
    const tableDroptScripts = options.dropTableScriptsFn && options.dropTableScriptsFn();
    if (tableDroptScripts && currDbVersion > 0) {
        tableDroptScripts.forEach(callback);
    }
    const tableCreateScripts = options.createTableScriptsFn && options.createTableScriptsFn();
    if (tableCreateScripts) {
        tableCreateScripts.forEach(callback);
    }
}
export class QueryProcessor {
    constructor(executorFn) {
        this._executorFn = executorFn;
    }
    process(transformer, initialValue) {
        const transformerAgent = { transform: transformer, initialValue, type: 0 };
        return new Promise(this._executorFn.bind(null, transformerAgent));
    }
    asGenerator(transformer) {
        const transformerAgent = { transform: transformer, type: 1 };
        return new Promise(this._executorFn.bind(null, transformerAgent));
    }
}
export var FIELD_TYPE;
(function (FIELD_TYPE) {
    FIELD_TYPE[FIELD_TYPE["NULL_ANDROID"] = 0] = "NULL_ANDROID";
    FIELD_TYPE[FIELD_TYPE["NULL_SQLITE"] = 5] = "NULL_SQLITE";
    FIELD_TYPE[FIELD_TYPE["INTEGER"] = 1] = "INTEGER";
    FIELD_TYPE[FIELD_TYPE["FLOAT"] = 2] = "FLOAT";
    FIELD_TYPE[FIELD_TYPE["STRING"] = 3] = "STRING";
    FIELD_TYPE[FIELD_TYPE["BLOB"] = 4] = "BLOB";
})(FIELD_TYPE || (FIELD_TYPE = {}));
export function readDbValue(fieldType, index, callback) {
    if (FIELD_TYPE[fieldType].includes("NULL"))
        return null;
    return parseToJsValue(callback(index, fieldType));
}
export function replaceQuestionMark(target, values) {
    if (!target)
        return null;
    if (!values)
        return target;
    let counter = 0;
    return target.replace(/\?/g, () => {
        const param = values[counter++];
        if (Array.isArray(param)) {
            return param.join();
        }
        return parseToDbValue(param);
    });
}
//# sourceMappingURL=sqlite-access.common.js.map